# linear regression for time-series data using a dummy variable
# y: nx1 vector of observations on the dependent variable
# X: nxk matrix of observations on k covariates


# Load data
y <- as.matrix(read.table("C:/LinearModels/Linear_Models/Lab_dummy_variables/Y.txt"))
X <- as.matrix(read.table("C:/LinearModels/Linear_Models/Lab_dummy_variables/X.txt"))
y
X
cor(X)

plot(X[,1],y)
plot(X[,2],y)

T <- length(y)
T1 <- 42

# Introduce a dummy variable
d <- c(rep(0, T1), rep(1, T - T1))
d

# Construct design matrix including the dummy variable
Xn <- cbind(d, X, diag(d) %*% X)
Xn <- cbind(1, Xn)  # Add a column of ones for the intercept term
Xn
dimX <- dim(Xn)
n=dimX[1]
k=dimX[2]-1

# Least squares estimation
XX <- t(Xn) %*% Xn
XXinv <- solve(XX)
XY <- t(Xn) %*% y
bhat <- XXinv %*% XY
bhat
e <- y - Xn %*% bhat

sigmahat <- sum(e^2) / (T - k - 1)

# Covariance matrix of bhat
covbhat <- sigmahat * XXinv

# Standard errors of regression coefficients
se <- sqrt(diag(covbhat))

# 95% confidence intervals
t_critical <- qt(0.975, T - k - 1)
CIs <- cbind(bhat - se * t_critical, bhat + se * t_critical)
CIs
